<?php
/**
 * An interface for peer-state lookup table wrappers
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface LookupablePeerState extends Lookupable {
	/**
	 * Checks whether given 'sender' is a new peer
	 *
	 * @param	$packageData	Raw package data
	 * @return	$isNewPeer		Whether 'sender' is a new peer to this node
	 */
	function isSenderNewPeer (array $packageData);

	/**
	 * Registers a peer with given package data. We use the session id from it
	 *
	 * @param	$packageData		Valid raw package data
	 * @param	$socketResource		A valid socket resource
	 * @return<>void
	 */
	function registerPeerByPackageData (array $packageData, $socketResource);

	/**
	 * Registers the given peer state and raw package data
	 *
	 * @param	$stateInstance	A PeerStateable class instance
	 * @param	$packageData	Valid package data array
	 * @return	void
	 */
	function registerPeerState (PeerStateable $stateInstance, array $packageData);

	/**
	 * Purges old entries of given socket resource. We use the IP address from that resource.
	 *
	 * @param	$socketResource		A valid socket resource
	 * @return	void
	 */
	function purgeOldEntriesBySocketResource ($socketResource);

	/**
	 * Checks whether a given peer state (in helper instance) is same as stored
	 * in database compared with the one from $helperInstance.
	 *
	 * @param	$helperInstance			An instance of a ConnectionHelper class
	 * @param	$packageData			Valid package data array
	 * @return	$isSamePeerState		Whether the peer's state is the same
	 */
	function isSamePeerState (ConnectionHelper $helperInstance, array $packageData);
}

// [EOF]
?>
