<?php
/**
 * A factory class for network packages
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class NetworkPackageFactory extends ObjectFactory {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Returns a singleton network package instance. If an instance is found in
	 * the registry it will be returned, else a new instance is created and
	 * stored in the same registry entry.
	 *
	 * @return	$packageInstance	A network package instance
	 */
	public static final function createNetworkPackageInstance () {
		// Do we have an instance in the registry?
		if (Registry::getRegistry()->instanceExists('network_package')) {
			// Then use this instance
			$packageInstance = Registry::getRegistry()->getInstance('network_package');
		} else {
			/*
			 * Prepare the compressor for our package, ZLIB should be fine but we
			 * keep it open here so you can experiment with the settings and don't
			 * need to touch this code.
			 */
			$compressorInstance = self::createObjectByConfiguredName('raw_package_compressor_class');

			// Prepare the decorator compressor (for later flawless and easy updates)
			$compressorInstance = self::createObjectByConfiguredName('deco_package_compressor_class', array($compressorInstance));

			/*
			 * Now prepare the network package for delivery so only need to do this
			 * once just before the "big announcement loop".
			 */
			$packageInstance = self::createObjectByConfiguredName('network_package_class', array($compressorInstance));

			// Set the instance in registry for further use
			Registry::getRegistry()->addInstance('network_package', $packageInstance);
		}

		// Return the instance
		return $packageInstance;
	}
}

// [EOF]
?>
