<?php
/**
 * A TaskHandlerInitializer filter for miners
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2014 Miner Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class MinerTaskHandlerInitializerFilter extends BaseMinerFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance		An instance of this filter class
	 */
	public static final function createMinerTaskHandlerInitializerFilter () {
		// Get a new instance
		$filterInstance = new MinerTaskHandlerInitializerFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @throws	FilterChainException	If the filter chain needs to be interrupted
	 * @todo	5% done
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get miner instance
		//$minerInstance = Registry::getRegistry()->getInstance('miner');

		// Get a new task handler instance
		$handlerInstance = ObjectFactory::createObjectByConfiguredName('task_handler_class');

		// Put the task handler in registry
		Registry::getRegistry()->addInstance('task_handler', $handlerInstance);

		// Register all tasks:
		//
		// 1) A task for fetching blocks from the network
		$taskInstance = ObjectFactory::createObjectByConfiguredName('miner_block_fetcher_task_class');
		$handlerInstance->registerTask('miner_block_fetcher', $taskInstance);

		/*
		 * 2) A task for generating a test "genesis" block. This "block"
		 * consists of several hashes of famous phrases or "catch lines" from
		 * free-software authors.
		 */
		$taskInstance = ObjectFactory::createObjectByConfiguredName('miner_test_genesis_block_producer_task_class');
		$handlerInstance->registerTask('miner_test_genesis_block_producer', $taskInstance);

		/*
		 * 3) A task for communicating into the locally running 'hub' node.
		 * This rask will check for new blocks on the mining network and
		 * tries to claim found blocks.
		 */
		$taskInstance = ObjectFactory::createObjectByConfiguredName('miner_node_communicator_task_class');
		$handlerInstance->registerTask('miner_node_communicator', $taskInstance);
	}
}

// [EOF]
?>
