<?php
/**
 * A NodeMessageDhtBootstrapAnswer handler
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2015 Hub Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class NodeMessageDhtBootstrapAnswerHandler extends BaseMessageHandler implements HandleableMessage, Registerable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set handler name
		$this->setHandlerName('message_announcement_answer');

		// Init message data array
		$this->messageDataElements = array(
			XmlDhtBootstrapAnswerTemplateEngine::DHT_BOOTSTRAP_DATA_EXTERNAL_ADDRESS,
			XmlDhtBootstrapAnswerTemplateEngine::DHT_BOOTSTRAP_DATA_INTERNAL_ADDRESS,
			XmlDhtBootstrapAnswerTemplateEngine::DHT_BOOTSTRAP_DATA_NODE_STATUS,
			XmlDhtBootstrapAnswerTemplateEngine::DHT_BOOTSTRAP_DATA_SESSION_ID,
			BaseXmlAnswerTemplateEngine::ANSWER_STATUS,
		);

		// Init message-data->configuration translation array
		$this->messageToConfig = array(
		/*
			XmlDhtBootstrapTemplateEngine::DHT_BOOTSTRAP_DATA_EXTERNAL_ADDRESS => 'your_external_address',
			XmlDhtBootstrapTemplateEngine::DHT_BOOTSTRAP_DATA_INTERNAL_ADDRESS => 'your_internal_address',
			XmlDhtBootstrapTemplateEngine::DHT_BOOTSTRAP_DATA_SESSION_ID       => 'your_session_id'
		*/
		);

		// Init config-copy array
		$this->configCopy = array(
			XmlDhtBootstrapAnswerTemplateEngine::DHT_BOOTSTRAP_DATA_EXTERNAL_ADDRESS => 'external_address',
			XmlDhtBootstrapAnswerTemplateEngine::DHT_BOOTSTRAP_DATA_INTERNAL_ADDRESS => 'internal_address',
			XmlDhtBootstrapAnswerTemplateEngine::DHT_BOOTSTRAP_DATA_NODE_STATUS      => 'node_status',
			XmlDhtBootstrapAnswerTemplateEngine::DHT_BOOTSTRAP_DATA_SESSION_ID       => 'session_id',
		);

		// Init array
		$this->searchData = array(
			XmlDhtBootstrapAnswerTemplateEngine::DHT_BOOTSTRAP_DATA_SESSION_ID,
			XmlDhtBootstrapAnswerTemplateEngine::DHT_BOOTSTRAP_DATA_EXTERNAL_ADDRESS,
		);
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$handlerInstance	An instance of a HandleableMessage class
	 */
	public final static function createNodeMessageDhtBootstrapAnswerHandler () {
		// Get new instance
		$handlerInstance = new NodeMessageDhtBootstrapAnswerHandler();

		// Return the prepared instance
		return $handlerInstance;
	}

	/**
	 * Handles data array of the message
	 *
	 * @param	$messageData		An array with message data to handle
	 * @param	$packageInstance	An instance of a Receivable class
	 * @return	void
	 * @throws	NoDhtBootstrapAttemptedException	If this DHT has not attempted to bootstrap
	 * @todo	~30% done
	 */
	public function handleMessageData (array $messageData, Receivable $packageInstance) {
		// Get DHT instance
		$dhtInstance = DhtObjectFactory::createDhtInstance('node');

		// Has this DHT attempted to bootstrap?
		if (!$dhtInstance->ifDhtIsBooting()) {
			/*
			 * This DHT has never bootstrapped, so it doesn't expect
			 * announcement answer messages.
			 */
			throw new NoDhtBootstrapAttemptedException(array($this, $dhtInstance, $messageData), self::EXCEPTION_DHT_BOOTSTRAP_NOT_ATTEMPTED);
		} // END - if

		// Unfinished
		$this->partialStub('UNHANDLED: messageData=' . print_r($messageData, TRUE));
	}

	/**
	 * Adds all required elements from given array into data set instance
	 *
	 * @param	$dataSetInstance	An instance of a StoreableCriteria class
	 * @param	$messageData		An array with all message data
	 * @return	void
	 */
	public function addArrayToDataSet (StoreableCriteria $dataSetInstance, array $messageData) {
		// Add generic first
		parent::addArrayToDataSet($dataSetInstance, $messageData);

		// Add all ements
		foreach ($this->messageDataElements as $key) {
			// Is it there?
			assert(isset($messageData[$key]));

			/*
			 * Add it, but remove any 'my-' prefixes as they are not used in
			 * database layer.
			 */
			$dataSetInstance->addCriteria(str_replace('my-', '', $key), $messageData[$key]);
		} // END - foreach
	}

	/**
	 * Initializes configuration data from given message data array
	 *
	 * @param	$messageData	An array with all message data
	 * @return	void
	 * @throws	UnsupportedOperationException	If this method is called
	 */
	protected function initMessageConfigurationData (array $messageData) {
		// Please don't call this method
		throw new UnsupportedOperationException(array($this, __FUNCTION__), self::EXCEPTION_UNSPPORTED_OPERATION);
	}

	/**
	 * Removes configuration data with given message data array from global
	 * configuration
	 *
	 * @param	$messageData	An array with all message data
	 * @return	void
	 * @throws	UnsupportedOperationException	If this method is called
	 */
	protected function removeMessageConfigurationData (array $messageData) {
		// Please don't call this method
		throw new UnsupportedOperationException(array($this, __FUNCTION__), self::EXCEPTION_UNSPPORTED_OPERATION);
	}
}

// [EOF]
?>
