<?php
/**
 * A Booting miner state class
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2014 Miner Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class MinerBootingState extends BaseMinerState implements Stateable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);

		// Set state name
		$this->setStateName('booting');
	}

	/**
	 * Creates an instance of this class
	 *
	 * @return	$stateInstance	An instance of a Stateable class
	 */
	public final static function createMinerBootingState () {
		// Get new instance
		$stateInstance = new MinerBootingState();

		// Debug message
		//* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('MINER-STATE: Has changed from ' . $minerInstance->getPrintableState() . ' to ' . $stateInstance->getStateName() . '.');

		// Return the prepared instance
		return $stateInstance;
	}

	/**
	 * Executes the state with given Executor instance
	 *
	 * @param	$executorInstance	An instance of a Executor class
	 * @return	void
	 */
	public function executeState (Executor $executorInstance) {
		// Debug message
		/* NOISY-DEBUG: */ self::createDebugInstance(__CLASS__)->debugOutput('MINER-STATE: Calling prepareBlockProduction() on ' . $executorInstance->__toString() . ' ...');

		// Now prepare the unit production to maybe become 'virgin' or 'active' if work/test units are there
		$executorInstance->prepareBlockProduction($this);
	}
}

// [EOF]
?>
